using System;
using System.Collections.Generic;

using skydiveLogs_api.Business.Interfaces;
using skydiveLogs_api.DomainService.Repositories;
using skydiveLogs_api.Domain;


namespace skydiveLogs_api.Business
{
    public class AircraftService : IAircraftService
    {
        public AircraftService(IAircraftRepository aircraftRepository)
        {
            _aircraftRepository = aircraftRepository;
        }

        public void AddNewAircraft(Aircraft newAircraft)
        {
            _aircraftRepository.Add(newAircraft);
        }

        public void DeleteAircraftById(int id)
        {
            throw new NotImplementedException();
        }

        public Aircraft GetAircraftById(int id)
        {
            return _aircraftRepository.GetById(id);
        }

        public IEnumerable<Aircraft> GetAllAircrafts()
        {
            return _aircraftRepository.GetAll();
        }

        public void UpdateAircraft(int id, Aircraft aircraft)
        {
            throw new NotImplementedException();
        }

        private readonly IAircraftRepository _aircraftRepository;
    }
}
